
package Bio::EnsEMBL::Hive::PipeConfig::MultiplyThenAdd1_conf;;

use strict;
use warnings;

use base ('Bio::EnsEMBL::Hive::PipeConfig::HiveGeneric_conf');


sub hive_meta_table {
    my ($self) = @_;
    return {
        %{$self->SUPER::hive_meta_table},       # here we inherit anything from the base class

        'hive_use_param_stack'  => 1,           # switch on the new param_stack mechanism
    };
}


sub pipeline_analyses {
    my ($self) = @_;
    return [
        {   -logic_name => 'b_array_into_elements',
            -module     => 'Bio::EnsEMBL::Hive::RunnableDB::JobFactory',
            -meadow_type=> 'LOCAL',     # do not bother the farm with such a simple task (and get it done faster)
            -parameters => {
                    'inputlist'     => '#b_array#',
                    'column_names'  => [ 'b_multiplier' ],
            },
            -flow_into => {
                '2->A' => [ 'take_b_apart' ],   # will create a semaphored fan of jobs; will use param_stack mechanism to pass parameters around
                'A->1' => [ 'add_full_products'  ],   # will create a semaphored funnel job to wait for the fan to complete and add the results
            },
        },

        {   -logic_name => 'take_b_apart',
            -module     => 'Bio::EnsEMBL::Hive::RunnableDB::LongMult::DigitFactory',
            -meadow_type=> 'LOCAL',     # do not bother the farm with such a simple task (and get it done faster)
            -analysis_capacity  =>  2,  # use per-analysis limiter
            -flow_into => {
                '2->A' => [ 'part_multiply' ],   # will create a semaphored fan of jobs; will use param_stack mechanism to pass parameters around
                'A->1' => [ 'add_partial_products'  ],   # will create a semaphored funnel job to wait for the fan to complete and add the results
            },
        },

        {   -logic_name => 'part_multiply',
            -module     => 'Bio::EnsEMBL::Hive::RunnableDB::LongMult::PartMultiply',
            -analysis_capacity  =>  4,  # use per-analysis limiter
            -flow_into => {
                1 => [ ':////accu?partial_product={digit}' ],
            },
        },
        
        {   -logic_name => 'add_partial_products',
            -module     => 'Bio::EnsEMBL::Hive::RunnableDB::LongMult::AddTogether',
            -flow_into => {
                1 => { ':////accu?b_array=[]' => { 'b_array' => '#result#' } },
            },
        },

        {   -logic_name => 'add_full_products',
            -module     => 'Bio::EnsEMBL::Hive::RunnableDB::Dummy',
            -parameters => {
                'sum' => '#expr( sum @{ #b_array# } )expr#',
            },
            -flow_into => {
                1 => { 'report' => { 'sum_of_products' => '#sum#' } }
            },
        },

        {   -logic_name => 'report',
            -module     => 'Bio::EnsEMBL::Hive::RunnableDB::Dummy',
        },
    ];
}

1;

